@@ -15,9 +15,10 @@ class DatabaseVersionCommand extends BaseCommand
             ->setDescription('Show database schema version');
     }
 
-    protected function execute(InputInterface $input, OutputInterface $output)
+    protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $output->writeln('<info>Current version: '.DatabaseProvider::getSchemaVersion($this->container['db']).'</info>');
         $output->writeln('<info>Last version: '.\Schema\VERSION.'</info>');
+        return 0;
     }
 }
