@@ -2,6 +2,7 @@
 
 namespace Kanboard\Controller;
 
+use Kanboard\Core\Controller\AccessForbiddenException;
 use Kanboard\Core\Controller\PageNotFoundException;
 
 /**
@@ -106,6 +107,9 @@ class TaskCreationController extends BaseController
 
         if (isset($values['project_ids'])) {
             foreach ($values['project_ids'] as $project_id) {
+                if (! $this->projectPermissionModel->isUserAllowed($project_id, $this->userSession->getId())) {
+                    throw new AccessForbiddenException();
+                }
                 $this->taskProjectDuplicationModel->duplicateToProject($values['task_id'], $project_id);
             }
         }
