@@ -75,6 +75,10 @@ class AuthenticationManager extends Base
     {
         if ($this->userSession->isLogged()) {
             foreach ($this->filterProviders('SessionCheckProviderInterface') as $provider) {
+                if ($provider instanceof OptionalAuthenticationProviderInterface && ! $provider->isEnabled()) {
+                    continue;
+                }
+
                 if (! $provider->isValidSession()) {
                     $this->logger->debug('Invalidate session for '.$this->userSession->getUsername());
                     session_flush();
@@ -96,6 +100,10 @@ class AuthenticationManager extends Base
     public function preAuthentication()
     {
         foreach ($this->filterProviders('PreAuthenticationProviderInterface') as $provider) {
+            if ($provider instanceof OptionalAuthenticationProviderInterface && ! $provider->isEnabled()) {
+                continue;
+            }
+
             if ($provider->authenticate() && $this->userProfile->initialize($provider->getUser())) {
                 $this->dispatcher->dispatch(new AuthSuccessEvent($provider->getName()), self::EVENT_SUCCESS);
                 return true;
