@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => '.',
     'number.thousands_separator' => ',',
     'None' => '无',
@@ -525,7 +525,7 @@ return array(
     'INR - Indian Rupee' => '印度卢比',
     'JPY - Japanese Yen' => '日元',
     'NZD - New Zealand Dollar' => '新西兰元',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - 秘鲁索尔',
     'RSD - Serbian dinar' => '第纳尔',
     'CNY - Chinese Yuan' => '人民币',
     'USD - US Dollar' => '美元',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => '任务#%d的泳道已改变',
     'Assignee changed on task #%d' => '任务#%d的指派人已改变',
     '%d overdue tasks' => '%d条超期任务',
-    'Task #%d is overdue' => '任务#%d已超期',
     'No notification.' => '没有新通知',
     'Mark all as read' => '标记所有为已读',
     'Mark as read' => '标记为已读',
@@ -924,7 +923,6 @@ return array(
     'Auto' => '自动',
     'Related' => '相关的',
     'Attachment' => '附件',
-    'Title not found' => '标题未找到',
     'Web Link' => '网页链接',
     'External links' => '外部关联',
     'Add external link' => '添加外部关联',
@@ -1400,8 +1398,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => '按指派重排(Z-A)',
     'Reorder this column by due date (ASC)' => '按逾期时间重排(升序)',
     'Reorder this column by due date (DESC)' => '按逾期时间重排(降序)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => '按ID重新排序此列 (升序)',
+    'Reorder this column by id (DESC)' => '按ID重新排序此列 (降序)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s 已将任务 #%d "%s" 移动到项目"%s" ',
     'Task #%d "%s" has been moved to the project "%s"' => '任务 #%d "%s" 已被移动到项目 "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => '当任务即将在指定天数内超期时移动到另一栏',
@@ -1432,38 +1430,43 @@ return array(
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '你所上传的文件不是有效图像！(只有*.gif, *.jpg, *.jpeg and *.png才被允许！)',
     'Automatically set the due date when the task is moved away from a specific column' => '当任务离开指定栏目时自动设置到期时间',
     'No other projects found.' => '未找到其它项目。',
-    'Please choose a project you want to copy the tasks from.' => '请选择将要复制的任务所属的项目。',
-    'Import Tasks' => '引入任务',
-    'Copy' => '复制',
     'Tasks copied successfully.' => '任务复制成功。',
     'Unable to copy tasks.' => '无法复制任务。',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Theme' => '主题',
+    'Theme:' => '主题：',
+    'Light theme' => '浅色主题',
+    'Dark theme' => '深色主题',
+    'Automatic theme - Sync with system' => '自动主题 - 同步系统设置',
+    'Application managers or more' => '应用程序经理或更多',
+    'Administrators' => '管理员',
+    'Visibility:' => '可见性:',
+    'Standard users' => '标准用户',
+    'Visibility is required' => '可见性是必需的',
+    'The visibility should be an app role' => '可见性应为应用角色',
+    'Reply' => '回复',
+    '%s wrote: ' => '%s 写道：',
+    'Number of visible tasks in this column and swimlane' => '此列和泳道中可见任务的数量',
+    'Number of tasks in this swimlane' => '此泳道中的任务数',
+    'Unable to find another subtask in progress, you can close this window.' => '找不到另一个正在进行的子任务，您可以关闭此窗口。',
+    'This theme is invalid' => '此主题无效',
+    'This role is invalid' => '此角色无效',
+    'This timezone is invalid' => '此时区无效',
+    'This language is invalid' => '此语言无效',
+    'This URL is invalid' => '此URL无效',
+    'Date format invalid' => '日期格式无效',
+    'Time format invalid' => '时间格式无效',
+    'Invalid Mail transport' => '无效的邮件传输',
+    'Color invalid' => '颜色无效',
+    'This value must be greater or equal to %d' => '此值必须大于或等于 %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '在文件开头添加 BOM（Microsoft Excel 需要）',
+    'Just add these tag(s)' => '只需添加这些标签',
+    'Remove internal link(s)' => '移除内部链接',
+    'Import tasks from another project' => '从其他项目导入任务',
+    'Select the project to copy tasks from' => '选择要从中复制任务的项目',
+    'The total maximum allowed attachments size is %sB.' => '允许的附件总大小上限为 %sB。',
+    'Add attachments' => '添加附件',
+    'Task #%d "%s" is overdue' => '任务 #%d "%s" 已逾期',
+    'Enable notifications by default for all new users' => '默认启用所有新用户的通知',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => '如果未手动指定负责人，则在指定列中将任务分配给创建者',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => '如果未分配用户，则在列变更移动到指定列时将任务分配给已登录用户',
+];
