@@ -28,7 +28,8 @@ class TaskEventJobTest extends Base
 
     public function testWithMissingTask()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE, function () {
+        });
 
         $taskEventJob = new TaskEventJob($this->container);
         $taskEventJob->execute(42, array(TaskModel::EVENT_CREATE));
@@ -39,8 +40,10 @@ class TaskEventJobTest extends Base
 
     public function testTriggerCreateEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE, function () {});
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE_UPDATE, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE, function () {
+        });
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE_UPDATE, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $projectModel = new ProjectModel($this->container);
@@ -54,8 +57,10 @@ class TaskEventJobTest extends Base
 
     public function testTriggerUpdateEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_UPDATE, function () {});
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE_UPDATE, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_UPDATE, function () {
+        });
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_CREATE_UPDATE, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $taskModificationModel = new TaskModificationModel($this->container);
@@ -71,7 +76,8 @@ class TaskEventJobTest extends Base
 
     public function testTriggerAssigneeChangeEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_ASSIGNEE_CHANGE, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_ASSIGNEE_CHANGE, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $taskModificationModel = new TaskModificationModel($this->container);
@@ -87,7 +93,8 @@ class TaskEventJobTest extends Base
 
     public function testTriggerCloseEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_CLOSE, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_CLOSE, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $taskStatusModel = new TaskStatusModel($this->container);
@@ -103,7 +110,8 @@ class TaskEventJobTest extends Base
 
     public function testTriggerOpenEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_OPEN, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_OPEN, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $taskStatusModel = new TaskStatusModel($this->container);
@@ -120,7 +128,8 @@ class TaskEventJobTest extends Base
 
     public function testTriggerMovePositionEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_POSITION, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_POSITION, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $taskPositionModel = new TaskPositionModel($this->container);
@@ -137,7 +146,8 @@ class TaskEventJobTest extends Base
 
     public function testTriggerMoveColumnEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_COLUMN, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_COLUMN, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $taskPositionModel = new TaskPositionModel($this->container);
@@ -153,7 +163,8 @@ class TaskEventJobTest extends Base
 
     public function testTriggerMoveSwimlaneEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_SWIMLANE, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_SWIMLANE, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $taskPositionModel = new TaskPositionModel($this->container);
@@ -171,7 +182,8 @@ class TaskEventJobTest extends Base
 
     public function testTriggerMoveProjectEvent()
     {
-        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_PROJECT, function () {});
+        $this->container['dispatcher']->addListener(TaskModel::EVENT_MOVE_PROJECT, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $projectModel = new ProjectModel($this->container);
