@@ -20,7 +20,8 @@ class TaskLinkEventJobTest extends Base
 
     public function testWithMissingLink()
     {
-        $this->container['dispatcher']->addListener(TaskLinkModel::EVENT_CREATE_UPDATE, function () {});
+        $this->container['dispatcher']->addListener(TaskLinkModel::EVENT_CREATE_UPDATE, function () {
+        });
 
         $taskLinkEventJob = new TaskLinkEventJob($this->container);
         $taskLinkEventJob->execute(42, TaskLinkModel::EVENT_CREATE_UPDATE);
@@ -31,7 +32,8 @@ class TaskLinkEventJobTest extends Base
 
     public function testTriggerCreationEvents()
     {
-        $this->container['dispatcher']->addListener(TaskLinkModel::EVENT_CREATE_UPDATE, function () {});
+        $this->container['dispatcher']->addListener(TaskLinkModel::EVENT_CREATE_UPDATE, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $projectModel = new ProjectModel($this->container);
@@ -48,7 +50,8 @@ class TaskLinkEventJobTest extends Base
 
     public function testTriggerDeleteEvents()
     {
-        $this->container['dispatcher']->addListener(TaskLinkModel::EVENT_DELETE, function () {});
+        $this->container['dispatcher']->addListener(TaskLinkModel::EVENT_DELETE, function () {
+        });
 
         $taskCreationModel = new TaskCreationModel($this->container);
         $projectModel = new ProjectModel($this->container);
